==> hudi-0.9.0-rc1.src.tgz: hudi-0.9.0-rc1/hudi-client/hudi-client-common/src/main/java/org/apache/hudi/table/action/compact/OperationResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hudi.table.action.compact;

import org.apache.hudi.common.util.Option;

import java.io.Serializable;

/**
 * Holds Operation result. Used as a result container for Compaction Admin Client (running as part of Spark-launcher
 * process) to communicate results back to Hoodie CLI process.
 */
public class OperationResult<T> implements Serializable {

  private T operation;
  private boolean executed;
  private boolean success;
  private Option<Exception> exception;

  public OperationResult() {}

  public OperationResult(T operation, boolean success, Option<Exception> exception) {
    this.operation = operation;
    this.success = success;
    this.exception = exception;
    this.executed = true;
  }

  public OperationResult(T operation, boolean executed, boolean success, Option<Exception> exception) {
    this.operation = operation;
    this.success = success;
    this.exception = exception;
    this.executed = executed;
  }

  public T getOperation() {
    return operation;
  }

  public boolean isSuccess() {
    return success;
  }

  public boolean isExecuted() {
    return executed;
  }

  public Option<Exception> getException() {
    return exception;
  }

  @Override
  public String toString() {
    return "OperationResult{operation=" + operation + ", executed=" + executed + ", success=" + success
        + ", exception=" + exception + '}';
  }
}

==> hudi-1.0.0.src.tgz: hudi-1.0.0/hudi-client/hudi-client-common/src/main/java/org/apache/hudi/table/action/compact/OperationResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hudi.table.action.compact;

import org.apache.hudi.common.util.Option;

import java.io.Serializable;

/**
 * Holds Operation result. Used as a result container for Compaction Admin Client (running as part of Spark-launcher
 * process) to communicate results back to Hoodie CLI process.
 */
public class OperationResult<T> implements Serializable {

  private T operation;
  private boolean executed;
  private boolean success;
  private Option<Exception> exception;

  public OperationResult() {
  }

  public OperationResult(T operation, boolean success, Option<Exception> exception) {
    this.operation = operation;
    this.success = success;
    this.exception = exception;
    this.executed = true;
  }

  public OperationResult(T operation, boolean executed, boolean success, Option<Exception> exception) {
    this.operation = operation;
    this.success = success;
    this.exception = exception;
    this.executed = executed;
  }

  public T getOperation() {
    return operation;
  }

  public boolean isSuccess() {
    return success;
  }

  public boolean isExecuted() {
    return executed;
  }

  public Option<Exception> getException() {
    return exception;
  }

  @Override
  public String toString() {
    return "OperationResult{operation=" + operation + ", executed=" + executed + ", success=" + success
        + ", exception=" + exception + '}';
  }
}
